@@ -45,15 +45,8 @@ class Penalty:
     def __init__(self, stats):
         self.player_penalty = stats.playing_players
         self.cpu_penalty = 1.05 ** (100 * stats.system_load) * 10 - 10
-        self.null_frame_penalty = 0
-        self.deficit_frame_penalty = 0
-
-        if stats.frames_nulled != -1:
-            self.null_frame_penalty = (1.03 ** (500 * (stats.frames_nulled / 3000))) * 300 - 300
-            self.null_frame_penalty *= 2
-
-        if stats.frames_deficit != -1:
-            self.deficit_frame_penalty = (1.03 ** (500 * (stats.frames_deficit / 3000))) * 600 - 600
+        self.null_frame_penalty = ((1.03 ** (500 * (stats.frames_nulled / 3000))) * 300 - 300) * 2
+        self.deficit_frame_penalty = (1.03 ** (500 * (stats.frames_deficit / 3000))) * 600 - 600
 
         self.total = self.player_penalty + self.cpu_penalty + self.null_frame_penalty + self.deficit_frame_penalty
 
@@ -128,9 +121,9 @@ class Stats:
         self.lavalink_load = cpu['lavalinkLoad']
 
         frame_stats = data.get('frameStats', {})
-        self.frames_sent = frame_stats.get('sent', -1)
-        self.frames_nulled = frame_stats.get('nulled', -1)
-        self.frames_deficit = frame_stats.get('deficit', -1)
+        self.frames_sent = frame_stats.get('sent', 0)
+        self.frames_nulled = frame_stats.get('nulled', 0)
+        self.frames_deficit = frame_stats.get('deficit', 0)
         self.penalty = Penalty(self)
 
     @classmethod
